@@ -96,8 +96,8 @@ twoord.plot<-function(lx,ly,rx,ry,data=NULL,main="",xlim=NULL,lylim=NULL,
  # display the left axis
  if(is.na(lytickpos[1])) lytickpos<-pretty(ly)
  if(is.na(ylab.at)) ylab.at<-mean(lytickpos)
- color.axis(2,at=lytickpos,axlab=ylab,axlab.at=ylab.at,
-  col=ifelse(is.na(lcol),1,lcol),cex.axis=axislab.cex)
+ color.axis(2,at=lytickpos,axlab=ylab,axlab.at=ylab.at, 
+  col=ifelse(is.na(lcol),1,lcol),cex.axis=axislab.cex,cex = axislab.cex)
  # get the "right" y limits
  if(is.null(rylim)) {
   rylim<-range(ry,na.rm=TRUE)
@@ -124,7 +124,8 @@ twoord.plot<-function(lx,ly,rx,ry,data=NULL,main="",xlim=NULL,lylim=NULL,
  if(is.na(rylab.at)) rylab.at<-mean(rytickpos)
  if(!is.na(rylab.at)) rylab.at<-rylab.at*ymult+yoff
  # display the right axis
- color.axis(4,at=axat,labels=rylabels,axlab=rylab,axlab.at=rylab.at,
-  col=ifelse(is.na(rcol),1,rcol),cex.axis=axislab.cex)
- par(mar=oldmar,new=FALSE)
+ color.axis(4,at=axat,labels=rylabels,axlab=rylab, 
+  axlab.at=rylab.at,col=ifelse(is.na(rcol),1,rcol), 
+  cex.axis=axislab.cex,cex=axislab.cex)
+ par(mar=oldmar,new=FALSE,col.axis="black")
 }
